diff --git a/Disco.Client/Interop/Hardware.cs b/Disco.Client/Interop/Hardware.cs
index ae55a435..abd30a77 100644
--- a/Disco.Client/Interop/Hardware.cs
+++ b/Disco.Client/Interop/Hardware.cs
@@ -331,7 +331,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve BIOS information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve BIOS information from WMI", ex);
}
}
@@ -394,7 +394,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve ComputerSystem information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve ComputerSystem information from WMI", ex);
}
}
@@ -427,7 +427,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve ComputerSystem information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve ComputerSystem information from WMI", ex);
}
}
@@ -504,7 +504,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve BaseBoard information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve BaseBoard information from WMI", ex);
}
}
@@ -556,7 +556,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve ComputerSystemProduct information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve ComputerSystemProduct information from WMI", ex);
}
}
diff --git a/Disco.Client/Interop/Network.cs b/Disco.Client/Interop/Network.cs
index 17804f5e..e3a15da5 100644
--- a/Disco.Client/Interop/Network.cs
+++ b/Disco.Client/Interop/Network.cs
@@ -68,7 +68,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve NetworkAdapter information from WMI", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve NetworkAdapter information from WMI", ex);
}
}
diff --git a/Disco.Client/Interop/WirelessNetwork.cs b/Disco.Client/Interop/WirelessNetwork.cs
index 2e5534c3..72bb38af 100644
--- a/Disco.Client/Interop/WirelessNetwork.cs
+++ b/Disco.Client/Interop/WirelessNetwork.cs
@@ -61,7 +61,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve Wireless NetworkAdapter information from WlanApi", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve Wireless NetworkAdapter information from WlanApi", ex);
}
}
@@ -102,7 +102,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to retrieve Wireless Profiles from WlanApi", ex);
+ throw new Exception("Disco ICT Client was unable to retrieve Wireless Profiles from WlanApi", ex);
}
}
@@ -356,7 +356,7 @@ namespace Disco.Client.Interop
}
catch (Exception ex)
{
- throw new Exception("Disco Client was unable to apply Wireless Profile Changes using WlanApi", ex);
+ throw new Exception("Disco ICT Client was unable to apply Wireless Profile Changes using WlanApi", ex);
}
}
diff --git a/Disco.ClientBootstrapper/BootstrapperLoop.cs b/Disco.ClientBootstrapper/BootstrapperLoop.cs
index 09dc0599..a9577cfc 100644
--- a/Disco.ClientBootstrapper/BootstrapperLoop.cs
+++ b/Disco.ClientBootstrapper/BootstrapperLoop.cs
@@ -85,12 +85,12 @@ namespace Disco.ClientBootstrapper
// Check for Network Connectivity
statusUI.UpdateStatus(null, "Detecting Network", "Checking network connectivity, Please wait...", true, -1);
- if (!Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (!Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
{
statusUI.UpdateStatus(null, "Detecting Network", "No network connectivity detected, Diagnosing...", true, -1);
statusUI_WriteAdapterInfo();
- if (!Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (!Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
{
// Check for Wireless
var hasWireless = (Interop.NetworkInterop.NetworkAdapters.Count(na => na.IsWireless) > 0);
@@ -105,17 +105,17 @@ namespace Disco.ClientBootstrapper
statusUI_WriteAdapterInfo();
statusUI.UpdateStatus(null, null, null, true, i);
Program.SleepThread(500, false);
- if (Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
break;
}
- if (!Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (!Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
{
statusUI.UpdateStatus(null, "Wireless Network Failed", "Unable to connect to the wireless network, please connect the network cable...", false);
Program.SleepThread(3000, false);
}
}
- if (!Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (!Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
{
// Instruct user to connect network cable
statusUI.UpdateStatus(null, "Please connect the network cable", null);
@@ -124,13 +124,13 @@ namespace Disco.ClientBootstrapper
statusUI_WriteAdapterInfo();
statusUI.UpdateStatus(null, null, null, true, i);
Program.SleepThread(500, false);
- if (Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
break;
}
}
}
- if (!Interop.NetworkInterop.PingDisco(DiscoServerName))
+ if (!Interop.NetworkInterop.PingDiscoIct(DiscoServerName))
{
// Client Failed
if (this.mLoopCompleteCallback != null)
diff --git a/Disco.ClientBootstrapper/BootstrapperWorkstationInstall.vbs b/Disco.ClientBootstrapper/BootstrapperWorkstationInstall.vbs
index 2f6b883f..ccfb05b7 100644
--- a/Disco.ClientBootstrapper/BootstrapperWorkstationInstall.vbs
+++ b/Disco.ClientBootstrapper/BootstrapperWorkstationInstall.vbs
@@ -8,4 +8,4 @@ BootstrapperLocation = Mid(WScript.ScriptFullName, 1, InStrRev(WScript.ScriptFul
Call objShell.Run("""" & BootstrapperLocation & """ /Install", , True)
-WScript.Echo "Disco Client Bootstrapper Installed"
\ No newline at end of file
+WScript.Echo "Disco ICT Client Bootstrapper Installed"
\ No newline at end of file
diff --git a/Disco.ClientBootstrapper/FormStatus.Designer.cs b/Disco.ClientBootstrapper/FormStatus.Designer.cs
index e8043801..20d0a21e 100644
--- a/Disco.ClientBootstrapper/FormStatus.Designer.cs
+++ b/Disco.ClientBootstrapper/FormStatus.Designer.cs
@@ -85,7 +85,7 @@
this.labelVersion.Name = "labelVersion";
this.labelVersion.Size = new System.Drawing.Size(167, 20);
this.labelVersion.TabIndex = 0;
- this.labelVersion.Text = "Disco Bootstrapper v";
+ this.labelVersion.Text = "Disco ICT Bootstrapper v";
this.labelVersion.TextAlign = System.Drawing.ContentAlignment.TopRight;
//
// FormStatus
@@ -106,7 +106,7 @@
this.ShowIcon = false;
this.ShowInTaskbar = false;
this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
- this.Text = "Disco - Client Bootstrapper";
+ this.Text = "Disco ICT - Client Bootstrapper";
this.TopMost = true;
this.TransparencyKey = System.Drawing.Color.Magenta;
this.ResumeLayout(false);
diff --git a/Disco.ClientBootstrapper/Interop/NetworkInterop.cs b/Disco.ClientBootstrapper/Interop/NetworkInterop.cs
index 2419abc2..c22fc811 100644
--- a/Disco.ClientBootstrapper/Interop/NetworkInterop.cs
+++ b/Disco.ClientBootstrapper/Interop/NetworkInterop.cs
@@ -165,7 +165,7 @@ namespace Disco.ClientBootstrapper.Interop
}
}
- public static bool PingDisco(string ServerName)
+ public static bool PingDiscoIct(string ServerName)
{
using (Ping p = new Ping())
{
diff --git a/Disco.Data/Repository/DiscoDatabaseConnectionFactory.cs b/Disco.Data/Repository/DiscoDatabaseConnectionFactory.cs
index 14743084..a401bbcd 100644
--- a/Disco.Data/Repository/DiscoDatabaseConnectionFactory.cs
+++ b/Disco.Data/Repository/DiscoDatabaseConnectionFactory.cs
@@ -71,7 +71,7 @@ namespace Disco.Data.Repository
var connectionString = DiscoDataContextConnectionString;
if (connectionString == null)
{
- throw new InvalidOperationException("The Disco DataContext Connection String has not been configured");
+ throw new InvalidOperationException("The Disco ICT DataContext Connection String has not been configured");
}
// Build DiscoDataContext - Use Default Connection Factory (SQLClient)
diff --git a/Disco.Models/Services/Devices/Exporting/DeviceExportOptions.cs b/Disco.Models/Services/Devices/Exporting/DeviceExportOptions.cs
index 72391130..7dd1031c 100644
--- a/Disco.Models/Services/Devices/Exporting/DeviceExportOptions.cs
+++ b/Disco.Models/Services/Devices/Exporting/DeviceExportOptions.cs
@@ -20,15 +20,15 @@ namespace Disco.Models.Services.Devices.Exporting
public bool DeviceComputerName { get; set; }
[Display(ShortName = "Device", Name = "Last Network Logon", Description = "The last recorded time the device access the network")]
public bool DeviceLastNetworkLogon { get; set; }
- [Display(ShortName = "Device", Name = "Created Date", Description = "The date the device was created in Disco")]
+ [Display(ShortName = "Device", Name = "Created Date", Description = "The date the device was created in Disco ICT")]
public bool DeviceCreatedDate { get; set; }
- [Display(ShortName = "Device", Name = "First Enrolled Date", Description = "The date the device was first enrolled in Disco")]
+ [Display(ShortName = "Device", Name = "First Enrolled Date", Description = "The date the device was first enrolled in Disco ICT")]
public bool DeviceFirstEnrolledDate { get; set; }
- [Display(ShortName = "Device", Name = "Last Enrolled Date", Description = "The date the device was last enrolled in Disco")]
+ [Display(ShortName = "Device", Name = "Last Enrolled Date", Description = "The date the device was last enrolled in Disco ICT")]
public bool DeviceLastEnrolledDate { get; set; }
[Display(ShortName = "Device", Name = "Enrolment Trusted", Description = "The device is trusted to complete an unauthenticated enrolment")]
public bool DeviceAllowUnauthenticatedEnrol { get; set; }
- [Display(ShortName = "Device", Name = "Decommissioned Date", Description = "The date the device was decommissioned in Disco")]
+ [Display(ShortName = "Device", Name = "Decommissioned Date", Description = "The date the device was decommissioned in Disco ICT")]
public bool DeviceDecommissionedDate { get; set; }
[Display(ShortName = "Device", Name = "Decommissioned Reason", Description = "The reason the device was decommissioned")]
public bool DeviceDecommissionedReason { get; set; }
diff --git a/Disco.Models/Services/Devices/Importing/DeviceImportFieldTypes.cs b/Disco.Models/Services/Devices/Importing/DeviceImportFieldTypes.cs
index fbe02c29..bdf4b8d3 100644
--- a/Disco.Models/Services/Devices/Importing/DeviceImportFieldTypes.cs
+++ b/Disco.Models/Services/Devices/Importing/DeviceImportFieldTypes.cs
@@ -14,7 +14,7 @@ namespace Disco.Models.Services.Devices.Importing
DeviceLocation,
[Display(Name = "Device Enrolment Trusted", Description = "The device is trusted to complete an unauthenticated enrolment")]
DeviceAllowUnauthenticatedEnrol,
- [Display(Name = "Device Decommissioned Date", Description = "The date the device was decommissioned in Disco")]
+ [Display(Name = "Device Decommissioned Date", Description = "The date the device was decommissioned in Disco ICT")]
DeviceDecommissionedDate,
[Display(Name = "Device Decommissioned Reason", Description = "The reason the device was decommissioned")]
DeviceDecommissionedReason,
diff --git a/Disco.Services/Authorization/AccessDeniedException.cs b/Disco.Services/Authorization/AccessDeniedException.cs
index 5aced150..f97479cc 100644
--- a/Disco.Services/Authorization/AccessDeniedException.cs
+++ b/Disco.Services/Authorization/AccessDeniedException.cs
@@ -19,7 +19,7 @@ namespace Disco.Services.Authorization
{
if (message == null)
{
- return "Your account does not have the required permission to access this Disco feature.";
+ return "Your account does not have the required permission to access this Disco ICT feature.";
}
else
{
diff --git a/Disco.Services/Authorization/AuthorizationToken.cs b/Disco.Services/Authorization/AuthorizationToken.cs
index 2bda4bec..22f000ba 100644
--- a/Disco.Services/Authorization/AuthorizationToken.cs
+++ b/Disco.Services/Authorization/AuthorizationToken.cs
@@ -44,7 +44,7 @@ namespace Disco.Services.Authorization
#region Token Accessors
internal const string RequireAuthenticationMessage = "This feature requires authentication.";
- internal const string RequireDiscoAuthorizationMessage = "Your account does not have the required permission to access this feature. This feature requires your account to be included in at least one Disco Authorization Role.";
+ internal const string RequireDiscoAuthorizationMessage = "Your account does not have the required permission to access this feature. This feature requires your account to be included in at least one Disco ICT Authorization Role.";
internal const string RequireMessageTemplate = "Your account does not have the required permission to access this feature.\r\n";
internal const string RequireMessageSingleTemplate = RequireMessageTemplate + "This feature requires the following permission:\r\n- {0}";
internal const string RequireAllMessageTemplate = RequireMessageTemplate + "This feature requires permission for:\r\n- {0}";
diff --git a/Disco.Services/Authorization/Roles/ClaimGroups/Configuration/ConfigClaims.cs b/Disco.Services/Authorization/Roles/ClaimGroups/Configuration/ConfigClaims.cs
index daee3083..6b2ac54e 100644
--- a/Disco.Services/Authorization/Roles/ClaimGroups/Configuration/ConfigClaims.cs
+++ b/Disco.Services/Authorization/Roles/ClaimGroups/Configuration/ConfigClaims.cs
@@ -14,7 +14,7 @@ using Disco.Services.Authorization.Roles.ClaimGroups.Configuration.UserFlag;
namespace Disco.Services.Authorization.Roles.ClaimGroups.Configuration
{
- [ClaimDetails("Configuration", "Permissions related to Disco Configuration")]
+ [ClaimDetails("Configuration", "Permissions related to Disco ICT Configuration")]
public class ConfigClaims : BaseRoleClaimGroup
{
public ConfigClaims()
diff --git a/Disco.Services/Authorization/Roles/RoleCache.cs b/Disco.Services/Authorization/Roles/RoleCache.cs
index edd177b4..a08f9414 100644
--- a/Disco.Services/Authorization/Roles/RoleCache.cs
+++ b/Disco.Services/Authorization/Roles/RoleCache.cs
@@ -149,7 +149,7 @@ namespace Disco.Services.Authorization.Roles
}
///
- /// Migrates authorization role claims to conform with changes to Disco since the last release.
+ /// Migrates authorization role claims to conform with changes to Disco ICT since the last release.
/// Claims are only added when the meaning of an existing claim has changed (or expanded/contracted) to improve the migration experience.
///
private static void MigrateAuthorizationRoles(DiscoDataContext Database)
diff --git a/Disco.Services/Authorization/Roles/RoleClaims.cs b/Disco.Services/Authorization/Roles/RoleClaims.cs
index 2bd02d29..b677e971 100644
--- a/Disco.Services/Authorization/Roles/RoleClaims.cs
+++ b/Disco.Services/Authorization/Roles/RoleClaims.cs
@@ -19,7 +19,7 @@ namespace Disco.Services.Authorization.Roles
[ClaimDetails("Computer Account", "Represents a computer account", true)]
public bool ComputerAccount { get; set; }
- [ClaimDetails("Disco Administrator Account", "Represents a Disco Administrator account", true)]
+ [ClaimDetails("Disco Administrator Account", "Represents a Disco ICT Administrator account", true)]
public bool DiscoAdminAccount { get; set; }
public ConfigClaims Config { get; set; }
diff --git a/Disco.Services/Devices/Enrolment/DeviceEnrolment.cs b/Disco.Services/Devices/Enrolment/DeviceEnrolment.cs
index 2359a598..ac5f4d3b 100644
--- a/Disco.Services/Devices/Enrolment/DeviceEnrolment.cs
+++ b/Disco.Services/Devices/Enrolment/DeviceEnrolment.cs
@@ -140,7 +140,7 @@ namespace Disco.Services.Devices.Enrolment
}
}
- EnrolmentLog.LogSessionProgress(sessionId, 100, "Disconnected, Starting Disco Enrolment");
+ EnrolmentLog.LogSessionProgress(sessionId, 100, "Disconnected, Starting Disco ICT Enrolment");
MacSecureEnrolResponse response = MacSecureEnrolResponse.FromMacEnrolResponse(MacEnrol(Database, trustedRequest, true, sessionId));
EnrolmentLog.LogSessionFinished(sessionId);
MacSecureEnrol = response;
@@ -330,7 +330,7 @@ namespace Disco.Services.Devices.Enrolment
EnrolmentLog.LogSessionProgress(sessionId, 13, "Loading Device Data");
Device RepoDevice = Database.Devices.Include("AssignedUser").Include("DeviceModel").Include("DeviceProfile").Where(d => d.SerialNumber == Request.SerialNumber).FirstOrDefault();
- EnrolmentLog.LogSessionProgress(sessionId, 15, "Discovering User/Device Disco Permissions");
+ EnrolmentLog.LogSessionProgress(sessionId, 15, "Discovering User/Device Disco ICT Permissions");
if (isAuthenticated)
{
if (!authenticatedToken.Has(Claims.Device.Actions.EnrolDevices))
diff --git a/Disco.Services/Devices/Enrolment/EnrolmentLog.cs b/Disco.Services/Devices/Enrolment/EnrolmentLog.cs
index f123615f..2e849c05 100644
--- a/Disco.Services/Devices/Enrolment/EnrolmentLog.cs
+++ b/Disco.Services/Devices/Enrolment/EnrolmentLog.cs
@@ -408,7 +408,7 @@ namespace Disco.Services.Devices.Enrolment
Id = (int)EventTypeIds.SessionTaskAddedDevice,
ModuleId = _ModuleId,
Name = "Task - Added Device",
- Format = "Creating Disco Device {1}",
+ Format = "Creating Disco ICT Device {1}",
Severity = 0,
UseLive = true,
UsePersist = true,
@@ -419,7 +419,7 @@ namespace Disco.Services.Devices.Enrolment
Id = (int)EventTypeIds.SessionTaskUpdatingDevice,
ModuleId = _ModuleId,
Name = "Task - Updating Device",
- Format = "Updating Disco Device {1}",
+ Format = "Updating Disco ICT Device {1}",
Severity = 0,
UseLive = true,
UsePersist = true,
diff --git a/Disco.Services/Expressions/Extensions/DataExt.cs b/Disco.Services/Expressions/Extensions/DataExt.cs
index 27c83b66..254fb4a8 100644
--- a/Disco.Services/Expressions/Extensions/DataExt.cs
+++ b/Disco.Services/Expressions/Extensions/DataExt.cs
@@ -13,7 +13,7 @@ namespace Disco.Services.Expressions.Extensions
private static SqlConnection BuildSqlConnection(string Server, string Database, string Username, string Password)
{
var dbConnectionStringBuilder = new SqlConnectionStringBuilder();
- dbConnectionStringBuilder.ApplicationName = "Disco";
+ dbConnectionStringBuilder.ApplicationName = "Disco ICT";
dbConnectionStringBuilder.DataSource = Server;
dbConnectionStringBuilder.InitialCatalog = Database;
dbConnectionStringBuilder.MultipleActiveResultSets = true;
diff --git a/Disco.Services/Interop/ActiveDirectory/ADDomainController.cs b/Disco.Services/Interop/ActiveDirectory/ADDomainController.cs
index deacfa8e..ed3b4b48 100644
--- a/Disco.Services/Interop/ActiveDirectory/ADDomainController.cs
+++ b/Disco.Services/Interop/ActiveDirectory/ADDomainController.cs
@@ -340,7 +340,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public string OfflineDomainJoinProvision(string ComputerSamAccountName, string OrganisationalUnit, ref ADMachineAccount MachineAccount, out string DiagnosticInformation)
{
if (MachineAccount != null && MachineAccount.IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", MachineAccount.DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", MachineAccount.DistinguishedName));
if (!IsWritable)
throw new InvalidOperationException(string.Format("The domain controller [{0}] is not writable. This action (Offline Domain Join Provision) requires a writable domain controller.", Name));
diff --git a/Disco.Services/Interop/ActiveDirectory/ADMachineAccount.cs b/Disco.Services/Interop/ActiveDirectory/ADMachineAccount.cs
index d15dfea9..9bbf0908 100644
--- a/Disco.Services/Interop/ActiveDirectory/ADMachineAccount.cs
+++ b/Disco.Services/Interop/ActiveDirectory/ADMachineAccount.cs
@@ -227,7 +227,7 @@ namespace Disco.Services.Interop.ActiveDirectory
private void SetNetbootGUID(ADDomainController WritableDomainController, Guid updatedNetbootGUID)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (NetbootGUID != updatedNetbootGUID)
{
@@ -248,7 +248,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetDescription(ADDomainController WritableDomainController, string Description)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.Description != Description)
{
@@ -349,7 +349,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void EnableAccount(ADDomainController WritableDomainController)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (IsDisabled)
{
@@ -377,7 +377,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public bool UpdateNetbootGUID(ADDomainController WritableDomainController, string UUID, string MACAddress)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
Guid netbootGUID = Guid.Empty;
@@ -428,7 +428,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void MoveOrganisationalUnit(ADDomainController WritableDomainController, string NewOrganisationUnit)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
var parentDistinguishedName = ParentDistinguishedName;
diff --git a/Disco.Services/Interop/ActiveDirectory/ADUserAccount.cs b/Disco.Services/Interop/ActiveDirectory/ADUserAccount.cs
index a3261e69..475f8f94 100644
--- a/Disco.Services/Interop/ActiveDirectory/ADUserAccount.cs
+++ b/Disco.Services/Interop/ActiveDirectory/ADUserAccount.cs
@@ -296,7 +296,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void EnableAccount(ADDomainController WritableDomainController)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (IsDisabled)
{
@@ -324,7 +324,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetDisplayName(ADDomainController WritableDomainController, string DisplayName)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.DisplayName != DisplayName)
{
@@ -357,7 +357,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetSurname(ADDomainController WritableDomainController, string Surname)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.Surname != Surname)
{
@@ -390,7 +390,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetGivenName(ADDomainController WritableDomainController, string GivenName)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.GivenName != GivenName)
{
@@ -423,7 +423,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetEmail(ADDomainController WritableDomainController, string Email)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.Email != Email)
{
@@ -456,7 +456,7 @@ namespace Disco.Services.Interop.ActiveDirectory
public void SetPhone(ADDomainController WritableDomainController, string Phone)
{
if (IsCriticalSystemObject)
- throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco refuses to modify it", DistinguishedName));
+ throw new InvalidOperationException(string.Format("This account {0} is a Critical System Active Directory Object and Disco ICT refuses to modify it", DistinguishedName));
if (this.Phone != Phone)
{
diff --git a/Disco.Services/Interop/ActiveDirectory/ActiveDirectoryManagedGroups.cs b/Disco.Services/Interop/ActiveDirectory/ActiveDirectoryManagedGroups.cs
index cd3db466..0b0c0a85 100644
--- a/Disco.Services/Interop/ActiveDirectory/ActiveDirectoryManagedGroups.cs
+++ b/Disco.Services/Interop/ActiveDirectory/ActiveDirectoryManagedGroups.cs
@@ -80,7 +80,7 @@ namespace Disco.Services.Interop.ActiveDirectory
if (group == null)
throw new ArgumentException(string.Format("The group [{0}] wasn't found", GroupId), "DevicesLinkedGroup");
if (group.GetPropertyValue("isCriticalSystemObject"))
- throw new ArgumentException(string.Format("The group [{0}] is a Critical System Active Directory Object and Disco refuses to modify it", group.DistinguishedName), "DevicesLinkedGroup");
+ throw new ArgumentException(string.Format("The group [{0}] is a Critical System Active Directory Object and Disco ICT refuses to modify it", group.DistinguishedName), "DevicesLinkedGroup");
GroupId = group.Id;
@@ -219,7 +219,7 @@ namespace Disco.Services.Interop.ActiveDirectory
using (var adGroupEntry = ActiveDirectory.Context.RetrieveDirectoryEntry(adGroup.DistinguishedName, new string[] { "member", "isCriticalSystemObject" }))
{
if (adGroupEntry.Entry.Properties.Value("isCriticalSystemObject"))
- throw new InvalidOperationException(string.Format("This group [{0}] is a Critical System Active Directory Object and Disco refuses to modify it", adGroup.DistinguishedName));
+ throw new InvalidOperationException(string.Format("This group [{0}] is a Critical System Active Directory Object and Disco ICT refuses to modify it", adGroup.DistinguishedName));
var adGroupEntryMembers = adGroupEntry.Entry.Properties["member"];
foreach (var item in actionItems)
@@ -369,7 +369,7 @@ namespace Disco.Services.Interop.ActiveDirectory
using (var adGroupEntry = ActiveDirectory.Context.RetrieveDirectoryEntry(adGroup.DistinguishedName, new string[] { "isCriticalSystemObject", "description", "member" }))
{
if (adGroupEntry.Entry.Properties.Value("isCriticalSystemObject"))
- throw new InvalidOperationException(string.Format("This group [{0}] is a Critical System Active Directory Object and Disco refuses to modify it", adGroup.DistinguishedName));
+ throw new InvalidOperationException(string.Format("This group [{0}] is a Critical System Active Directory Object and Disco ICT refuses to modify it", adGroup.DistinguishedName));
// Update Description
var groupDescription = string.Format("Disco ICT: {0}", actionGroup.Item1.GroupDescription);
diff --git a/Disco.Services/Jobs/JobExtensions.cs b/Disco.Services/Jobs/JobExtensions.cs
index 99a1a3f9..4e357fcb 100644
--- a/Disco.Services/Jobs/JobExtensions.cs
+++ b/Disco.Services/Jobs/JobExtensions.cs
@@ -262,7 +262,7 @@ namespace Disco.Services
public static string GenerateFaultDescriptionFooter(this Job j, DiscoDataContext Database, PluginFeatureManifest WarrantyProviderDefinition)
{
var versionDisco = System.Reflection.Assembly.GetExecutingAssembly().GetName().Version;
- return string.Format("Automation by Disco v{0}.{1}.{2:0000}.{3:0000} (Provider: {4} v{5})",
+ return string.Format("Automation by Disco ICT v{0}.{1}.{2:0000}.{3:0000} (Provider: {4} v{5})",
versionDisco.Major, versionDisco.Minor, versionDisco.Build, versionDisco.Revision, WarrantyProviderDefinition.Id, WarrantyProviderDefinition.PluginManifest.Version.ToString(4));
}
diff --git a/Disco.Services/Logging/SystemLog.cs b/Disco.Services/Logging/SystemLog.cs
index ac4a31bc..ab1e03e8 100644
--- a/Disco.Services/Logging/SystemLog.cs
+++ b/Disco.Services/Logging/SystemLog.cs
@@ -148,7 +148,7 @@ namespace Disco.Services.Logging
Id = (int)EventTypeIds.Uninitialized,
ModuleId = _ModuleId,
Name = "Disco Uninitialized",
- Format = "Disco Uninitialized",
+ Format = "Disco ICT Uninitialized",
Severity = (int)LogEventType.Severities.Information,
UseLive = false, UsePersist = true, UseDisplay = false }
};
diff --git a/Disco.Services/Plugins/Features/UIExtension/UIExtensions.cs b/Disco.Services/Plugins/Features/UIExtension/UIExtensions.cs
index b8dd198d..b23a7e55 100644
--- a/Disco.Services/Plugins/Features/UIExtension/UIExtensions.cs
+++ b/Disco.Services/Plugins/Features/UIExtension/UIExtensions.cs
@@ -52,7 +52,7 @@ namespace Disco.Services.Plugins.Features.UIExtension
if (uiExtResults != null && uiExtResults.Count > 0)
{
- page.WriteLiteral("");
+ page.WriteLiteral("");
page.WriteLiteral("\n");
foreach (var uiExtResult in uiExtResults)
{
@@ -62,7 +62,7 @@ namespace Disco.Services.Plugins.Features.UIExtension
page.WriteLiteral(string.Format("\n", extensionDescription));
}
page.WriteLiteral("\n
");
- page.WriteLiteral("\n");
+ page.WriteLiteral("\n");
}
}
diff --git a/Disco.Services/Plugins/Plugins.cs b/Disco.Services/Plugins/Plugins.cs
index 26d9f907..45a702a0 100644
--- a/Disco.Services/Plugins/Plugins.cs
+++ b/Disco.Services/Plugins/Plugins.cs
@@ -314,9 +314,9 @@ namespace Disco.Services.Plugins
throw new InvalidOperationException(string.Format("The plugin [{0} v{1}] is not compatible: {2}", pluginManifest.Id, pluginManifest.VersionFormatted, pluginIncompatible.Reason));
if (pluginManifest.HostVersionMin != null && pluginManifest.HostVersionMin > hostVersion)
- throw new InvalidOperationException(string.Format("The plugin [{0} v{1}] does not support this version of Disco (Requires v{2} or greater)", pluginManifest.Id, pluginManifest.VersionFormatted, pluginManifest.HostVersionMin.ToString()));
+ throw new InvalidOperationException(string.Format("The plugin [{0} v{1}] does not support this version of Disco ICT (Requires v{2} or greater)", pluginManifest.Id, pluginManifest.VersionFormatted, pluginManifest.HostVersionMin.ToString()));
if (pluginManifest.HostVersionMax != null && pluginManifest.HostVersionMax < hostVersion)
- throw new InvalidOperationException(string.Format("The plugin [{0} v{1}] does not support this version of Disco (Support expired as of v{2})", pluginManifest.Id, pluginManifest.VersionFormatted, pluginManifest.HostVersionMax.ToString()));
+ throw new InvalidOperationException(string.Format("The plugin [{0} v{1}] does not support this version of Disco ICT (Support expired as of v{2})", pluginManifest.Id, pluginManifest.VersionFormatted, pluginManifest.HostVersionMax.ToString()));
RegisterPluginAssemblyReferences(pluginManifest);
diff --git a/Disco.Services/Plugins/UninstallPluginTask.cs b/Disco.Services/Plugins/UninstallPluginTask.cs
index 3421ea0b..52a90d30 100644
--- a/Disco.Services/Plugins/UninstallPluginTask.cs
+++ b/Disco.Services/Plugins/UninstallPluginTask.cs
@@ -45,7 +45,7 @@ namespace Disco.Services.Plugins
File.Copy(manifestUninstallFileLocation, manifestDataUninstallFileLocation);
}
- Status.Finished("Restarting Disco, please wait...", "/Config/Plugins");
+ Status.Finished("Restarting Disco ICT, please wait...", "/Config/Plugins");
Plugins.RestartApp(2500);
}
diff --git a/Disco.Services/Plugins/UpdatePluginTask.cs b/Disco.Services/Plugins/UpdatePluginTask.cs
index 2954dd72..3a5ec190 100644
--- a/Disco.Services/Plugins/UpdatePluginTask.cs
+++ b/Disco.Services/Plugins/UpdatePluginTask.cs
@@ -88,7 +88,7 @@ namespace Disco.Services.Plugins
ExecuteTaskInternal(Status, pluginPackagesLocation, updatePlugins);
- Status.Finished("Restarting Disco, please wait...", "/Config/Plugins");
+ Status.Finished("Restarting Disco ICT, please wait...", "/Config/Plugins");
Plugins.RestartApp(2500);
}
diff --git a/Disco.Services/Plugins/UpdatePluginsAfterDiscoUpdateTask.cs b/Disco.Services/Plugins/UpdatePluginsAfterDiscoUpdateTask.cs
index d6074d70..939123b0 100644
--- a/Disco.Services/Plugins/UpdatePluginsAfterDiscoUpdateTask.cs
+++ b/Disco.Services/Plugins/UpdatePluginsAfterDiscoUpdateTask.cs
@@ -10,11 +10,11 @@ namespace Disco.Services.Plugins
{
private static object _startLock = new object();
- public override string TaskName { get { return "Updating Disco Plugins"; } }
+ public override string TaskName { get { return "Updating Disco ICT Plugins"; } }
protected override void ExecuteTask()
{
- Status.UpdateStatus(0, "Updating plugins after Disco update", "Starting, please wait...");
+ Status.UpdateStatus(0, "Updating plugins after Disco ICT update", "Starting, please wait...");
// Wait for App to Load (10 Seconds)
for (int i = 0; i < 10; i++)
@@ -33,7 +33,7 @@ namespace Disco.Services.Plugins
UpdatePluginTask.UpdateOffline(Status);
// Restart
- Status.Finished("Restarting Disco, please wait...", "/");
+ Status.Finished("Restarting Disco ICT, please wait...", "/");
Plugins.RestartApp(2500);
}
diff --git a/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.cshtml b/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.cshtml
index 99fa9c69..c4305daa 100644
--- a/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.cshtml
+++ b/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.cshtml
@@ -223,6 +223,6 @@ else
diff --git a/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.generated.cs b/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.generated.cs
index c17229bc..2041c3cc 100644
--- a/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.generated.cs
+++ b/Disco.Web/Areas/Config/Views/AuthorizationRole/Index.generated.cs
@@ -2,7 +2,7 @@
//------------------------------------------------------------------------------
//
// This code was generated by a tool.
-// Runtime Version:4.0.30319.34014
+// Runtime Version:4.0.30319.42000
//
// Changes to this file may cause incorrect behavior and will be lost if
// the code is regenerated.
@@ -27,7 +27,6 @@ namespace Disco.Web.Areas.Config.Views.AuthorizationRole
using System.Web.UI;
using System.Web.WebPages;
using Disco;
- using Disco.BI.Extensions;
using Disco.Models.Repository;
using Disco.Services;
using Disco.Services.Authorization;
@@ -469,11 +468,11 @@ WriteLiteral(" href=\"#\"");
WriteLiteral(" class=\"button\"");
-WriteLiteral(">Update Disco Administrators [");
+WriteLiteral(">Update Disco ICT Administrators [");
#line 226 "..\..\Areas\Config\Views\AuthorizationRole\Index.cshtml"
- Write(Model.AdministratorSubjects.Count);
+ Write(Model.AdministratorSubjects.Count);
#line default
diff --git a/Disco.Web/Areas/Config/Views/Config/Index.cshtml b/Disco.Web/Areas/Config/Views/Config/Index.cshtml
index c86db2d6..fa7b2375 100644
--- a/Disco.Web/Areas/Config/Views/Config/Index.cshtml
+++ b/Disco.Web/Areas/Config/Views/Config/Index.cshtml
@@ -28,7 +28,7 @@
{
@Html.ActionLinkClass("Plugins", MVC.Config.Plugins.Index(), "config")
}
@if (Authorization.Has(Claims.DiscoAdminAccount))
@@ -42,7 +42,7 @@
{
@Html.ActionLinkClass("Logging", MVC.Config.Logging.Index(), "config")
}
diff --git a/Disco.Web/Areas/Config/Views/Config/Index.generated.cs b/Disco.Web/Areas/Config/Views/Config/Index.generated.cs
index 9f073c61..fcad79be 100644
--- a/Disco.Web/Areas/Config/Views/Config/Index.generated.cs
+++ b/Disco.Web/Areas/Config/Views/Config/Index.generated.cs
@@ -2,7 +2,7 @@
//------------------------------------------------------------------------------
//
// This code was generated by a tool.
-// Runtime Version:4.0.30319.34014
+// Runtime Version:4.0.30319.42000
//
// Changes to this file may cause incorrect behavior and will be lost if
// the code is regenerated.
@@ -27,7 +27,6 @@ namespace Disco.Web.Areas.Config.Views.Config
using System.Web.UI;
using System.Web.WebPages;
using Disco;
- using Disco.BI.Extensions;
using Disco.Models.Repository;
using Disco.Services;
using Disco.Services.Authorization;
@@ -223,8 +222,8 @@ WriteLiteral(" \r\n");
+WriteLiteral(">\r\n Manage extensions to the Disco ICT platform.\r\n " +
+" \r\n");
#line 33 "..\..\Areas\Config\Views\Config\Index.cshtml"
@@ -323,8 +322,8 @@ WriteLiteral(" \r\n");
+WriteLiteral(">\r\n Export Log files from various Disco ICT Modules an" +
+"d view Live Logging.\r\n \r\n");
#line 47 "..\..\Areas\Config\Views\Config\Index.cshtml"
@@ -912,14 +911,14 @@ WriteLiteral(" class=\"fa fa-cloud-download info\"");
WriteLiteral(">\r\n An updated version of Disco is available
\r\n (Model.UpdateResponse.UrlLink
+, Tuple.Create(Tuple.Create("", 7825), Tuple.Create(Model.UpdateResponse.UrlLink
#line default
#line hidden
-, 7817), false)
+, 7825), false)
);
WriteLiteral(" class=\"button small alert\"");
diff --git a/Disco.Web/Areas/Config/Views/DocumentTemplate/ExpressionBrowser.cshtml b/Disco.Web/Areas/Config/Views/DocumentTemplate/ExpressionBrowser.cshtml
index c7dc0f04..b2257aa8 100644
--- a/Disco.Web/Areas/Config/Views/DocumentTemplate/ExpressionBrowser.cshtml
+++ b/Disco.Web/Areas/Config/Views/DocumentTemplate/ExpressionBrowser.cshtml
@@ -7,7 +7,7 @@
Html.BundleDeferred("~/ClientScripts/Modules/jQueryUI-DynaTree");
}
\r\n");
+"vileges as the Disco ICT Web App.
\r\n Only Install plugin" +
+"s from a trusted source.\r\n
\r\n \r\n\r\n");
#line 79 "..\..\Areas\Config\Views\Plugins\Install.cshtml"
@@ -488,9 +488,9 @@ WriteLiteral(">\r\n Warning: All plugins run with the same level of network pri" +
-"vileges as the Disco Web App.
\r\n Only install plugin" +
-"s from a trusted source.\r\n \r\n \r\n \r" +
-"\n");
+"vileges as the Disco ICT Web App.
\r\n Only install pl" +
+"ugins from a trusted source.\r\n \r\n \r\n \r\n");
#line 96 "..\..\Areas\Config\Views\Plugins\Install.cshtml"
diff --git a/Disco.Web/Areas/Config/Views/SystemConfig/Index.cshtml b/Disco.Web/Areas/Config/Views/SystemConfig/Index.cshtml
index f62887a3..d9ef3a0f 100644
--- a/Disco.Web/Areas/Config/Views/SystemConfig/Index.cshtml
+++ b/Disco.Web/Areas/Config/Views/SystemConfig/Index.cshtml
@@ -19,7 +19,7 @@
|
- Disco Version:
+ Disco ICT Version:
|
@@ -268,7 +268,7 @@
@Html.CheckBoxFor(m => m.ADSearchAllServers, new { disabled = "disabled" }) @Html.LabelFor(m => m.ADSearchAllServers)
- Disco will not search the entire directory which consists of more than @(Disco.Services.Interop.ActiveDirectory.ActiveDirectory.MaxAllServerSearch) servers. Only servers within this site will be searched.
+ Disco ICT will not search the entire directory which consists of more than @(Disco.Services.Interop.ActiveDirectory.ActiveDirectory.MaxAllServerSearch) servers. Only servers within this site will be searched.
}
@@ -277,7 +277,7 @@
@Html.CheckBoxFor(m => m.ADSearchAllServers) @Html.LabelFor(m => m.ADSearchAllServers) @AjaxHelpers.AjaxLoader()
- If this setting is enabled, Disco will query all servers within the directory rather than only servers within this site.
+ If this setting is enabled, Disco ICT will query all servers within the directory rather than only servers within this site.
\r\n");
+"while the Disco ICT database is created and/or validated \r\n\r\n\r\n");
}
}
diff --git a/Disco.Web/Views/InitialConfig/FileStore.cshtml b/Disco.Web/Views/InitialConfig/FileStore.cshtml
index d542efd5..15168fcf 100644
--- a/Disco.Web/Views/InitialConfig/FileStore.cshtml
+++ b/Disco.Web/Views/InitialConfig/FileStore.cshtml
@@ -42,7 +42,7 @@
Building and Validating File Store
- Please wait while the Disco File Store is created and/or validated
+ Please wait while the Disco ICT File Store is created and/or validated
Create Directory
diff --git a/Disco.Web/Views/InitialConfig/FileStore.generated.cs b/Disco.Web/Views/InitialConfig/FileStore.generated.cs
index 58f330af..cfee4540 100644
--- a/Disco.Web/Views/InitialConfig/FileStore.generated.cs
+++ b/Disco.Web/Views/InitialConfig/FileStore.generated.cs
@@ -2,7 +2,7 @@
//------------------------------------------------------------------------------
//
// This code was generated by a tool.
-// Runtime Version:4.0.30319.0
+// Runtime Version:4.0.30319.42000
//
// Changes to this file may cause incorrect behavior and will be lost if
// the code is regenerated.
@@ -27,7 +27,6 @@ namespace Disco.Web.Views.InitialConfig
using System.Web.UI;
using System.Web.WebPages;
using Disco;
- using Disco.BI.Extensions;
using Disco.Models.Repository;
using Disco.Services;
using Disco.Services.Authorization;
@@ -186,7 +185,8 @@ WriteLiteral(">\r\n \r\n \r\n Building and Validating File Store\r\n \r\n Please wai" +
-"t while the Disco File Store is created and/or validated \r\n \r\n\r\n \r\n@CommonHelpers.Breadcrumbs("Initial Configuration > Starting Disco")
+ @CommonHelpers.Breadcrumbs("Initial Configuration > Starting Disco ICT")
- Starting Disco
+ Starting Disco ICT
- Please wait while the Disco environment is initialized
+ Please wait while the Disco ICT environment is initialized
|
diff --git a/Disco.Services.Plugins.ManifestGenerator/Program.cs b/Disco.Services.Plugins.ManifestGenerator/Program.cs
index 41dc12e4..9b29680d 100644
--- a/Disco.Services.Plugins.ManifestGenerator/Program.cs
+++ b/Disco.Services.Plugins.ManifestGenerator/Program.cs
@@ -25,7 +25,7 @@ namespace Disco.Services.Plugins.ManifestGenerator
throw new ArgumentException($"File not found at: {assemblyFileInfo.FullName}");
}
- Console.WriteLine("Disco Plugin: Generating Manifest");
+ Console.WriteLine("Disco ICT Plugin: Generating Manifest");
AppDomain.CurrentDomain.AssemblyLoad += CurrentDomain_AssemblyLoad;
AppDomain.CurrentDomain.AssemblyResolve += CurrentDomain_AssemblyResolve;
@@ -55,7 +55,7 @@ namespace Disco.Services.Plugins.ManifestGenerator
}
catch (Exception ex)
{
- Console.WriteLine($"Disco Plugin: Warning: Unable to load reference '{referenceAssembly.FullName}'; {ex.Message}");
+ Console.WriteLine($"Disco ICT Plugin: Warning: Unable to load reference '{referenceAssembly.FullName}'; {ex.Message}");
}
}
}
@@ -68,9 +68,9 @@ namespace Disco.Services.Plugins.ManifestGenerator
File.WriteAllText(manifestFilePath, manifest.ToManifestFile());
- Console.WriteLine("Disco Plugin: Manifest Created");
+ Console.WriteLine("Disco ICT Plugin: Manifest Created");
- Console.WriteLine("Disco Plugin: Building Package");
+ Console.WriteLine("Disco ICT Plugin: Building Package");
var packageFileName = $"{manifest.Id}-{manifest.Version}.discoPlugin";
var packageFilePath = Path.Combine(assemblyFileInfo.DirectoryName, packageFileName);
@@ -81,7 +81,7 @@ namespace Disco.Services.Plugins.ManifestGenerator
existingPackages.Delete();
}
// Exclude Disco Provided Assemblies
List excludedFiles = PluginManifest.PluginExcludedAssemblies.ToList();
// Exclude the Package File
@@ -95,7 +95,7 @@ namespace Disco.Services.Plugins.ManifestGenerator
}
}
- Console.WriteLine($"Disco Plugin: Package Build: '{packageFileName}'");
+ Console.WriteLine($"Disco ICT Plugin: Package Build: '{packageFileName}'");
}
@@ -81,7 +81,7 @@ namespace Disco.Services.Plugins.ManifestGenerator
existingPackages.Delete();
}
- // Exclude Disco Provided Assemblies
+ // Exclude Disco ICT Provided Assemblies
List excludedFiles = PluginManifest.PluginExcludedAssemblies.ToList();
// Exclude the Package File
diff --git a/Disco.Services/Authorization/Claims.cs b/Disco.Services/Authorization/Claims.cs
index bd554e2d..33a3becd 100644
--- a/Disco.Services/Authorization/Claims.cs
+++ b/Disco.Services/Authorization/Claims.cs
@@ -220,14 +220,14 @@ namespace Disco.Services.Authorization
{ "User.ShowFlagAssignments", new Tuple, Action, string, string, bool>(c => c.User.ShowFlagAssignments, (c, v) => c.User.ShowFlagAssignments = v, "Show Users Flag Assignments", "Can show flags associated with users", false) },
{ "User.ShowJobs", new Tuple, Action, string, string, bool>(c => c.User.ShowJobs, (c, v) => c.User.ShowJobs = v, "Show Users Jobs", "Can show jobs associated with users", false) },
{ "ComputerAccount", new Tuple, Action, string, string, bool>(c => c.ComputerAccount, (c, v) => c.ComputerAccount = v, "Computer Account", "Represents a computer account", true) },
- { "DiscoAdminAccount", new Tuple, Action, string, string, bool>(c => c.DiscoAdminAccount, (c, v) => c.DiscoAdminAccount = v, "Disco Administrator Account", "Represents a Disco Administrator account", true) }
+ { "DiscoAdminAccount", new Tuple, Action, string, string, bool>(c => c.DiscoAdminAccount, (c, v) => c.DiscoAdminAccount = v, "Disco ICT Administrator Account", "Represents a Disco ICT Administrator account", true) }
};
#endregion
#region Role Claim Navigator
_claimNavigator =
new ClaimNavigatorItem("Claims", "Permissions", "Top-level node for all permissions", false, new List() {
- new ClaimNavigatorItem("Config", "Configuration", "Permissions related to Disco Configuration", false, new List() {
+ new ClaimNavigatorItem("Config", "Configuration", "Permissions related to Disco ICT Configuration", false, new List() {
new ClaimNavigatorItem("Config.DeviceBatch", "Device Batches", "Permissions related to Device Batches", false, new List() {
new ClaimNavigatorItem("Config.DeviceBatch.Configure", false),
new ClaimNavigatorItem("Config.DeviceBatch.Create", false),
@@ -749,7 +749,7 @@ namespace Disco.Services.Authorization
#region Role Claim Constants
/// Configuration
/// Permissions related to Disco Configuration
///
public static class Config
{
@@ -1917,8 +1917,8 @@ namespace Disco.Services.Authorization
///
public const string ComputerAccount = "ComputerAccount";
/// Disco Administrator Account
/// Represents a Disco Administrator account
///
public const string DiscoAdminAccount = "DiscoAdminAccount";
#endregion
@@ -749,7 +749,7 @@ namespace Disco.Services.Authorization
#region Role Claim Constants
/// Configuration
- /// Permissions related to Disco Configuration
+ /// Permissions related to Disco ICT Configuration
///
public static class Config
@@ -1917,8 +1917,8 @@ namespace Disco.Services.Authorization
///
public const string ComputerAccount = "ComputerAccount";
- /// Disco Administrator Account
- /// Represents a Disco Administrator account
+ /// Disco ICT Administrator Account
+ /// Represents a Disco ICT Administrator account
///
public const string DiscoAdminAccount = "DiscoAdminAccount";